@@ -1,7 +1,7 @@
 """Generate and upload automated circulars."""
 import ligo.followup_advocate
 
-from . import gracedb
+from . import legacy_gracedb as gracedb
 
 
 @gracedb.task(shared=False)
@@ -13,10 +13,20 @@ def create_initial_circular(graceid):
 @gracedb.task(shared=False)
 def create_emcoinc_circular(graceid):
     """Create and return the em_coinc circular txt."""
-    return ligo.followup_advocate.compose_RAVEN(graceid,
+    return ligo.followup_advocate.compose_raven(graceid,
                                                 client=gracedb.client)
 
 
+@gracedb.task(shared=False)
+def create_update_circular(graceid, update_types=['sky_localization',
+                                                  'em_bright',
+                                                  'p_astro']):
+    """Create and return update circular txt."""
+    return ligo.followup_advocate.compose_update(graceid,
+                                                 update_types=update_types,
+                                                 client=gracedb.client)
+
+
 @gracedb.task(shared=False)
 def create_retraction_circular(graceid):
     """Create and return retraction circular txt."""
