@@ -238,7 +238,7 @@ def dqr_json(state, summary):
         },
         {
             "href":
-            "https://git.ligo.org/emfollow/gwcelery/blob/master/gwcelery/tasks/detchar.py",  # noqa
+            "https://git.ligo.org/emfollow/gwcelery/blob/main/gwcelery/tasks/detchar.py",  # noqa
             "innerHTML": "a link to the source code in the gwcelery repo"
         }
     ]
