@@ -3,7 +3,7 @@ from unittest.mock import Mock
 
 import pytest
 
-from .. import app
+from .. import app, main
 from ..tools import nagios
 
 
@@ -15,22 +15,34 @@ def test_nagios_unknown_error(monkeypatch, capsys):
                         Mock(side_effect=RuntimeError))
 
     with pytest.raises(SystemExit) as excinfo:
-        app.start(['gwcelery', 'nagios'])
+        main(['gwcelery', 'nagios'])
     assert excinfo.value.code == nagios.NagiosPluginStatus.UNKNOWN
     out, err = capsys.readouterr()
     assert 'UNKNOWN: Unexpected error' in out
 
 
-def test_nagios(capsys, monkeypatch, socket_enabled, starter):
+@pytest.fixture
+def celery_worker_parameters():
+    return dict(
+        perform_ping_check=False,
+        queues=['celery', 'exttrig', 'openmp', 'superevent', 'voevent']
+    )
+
+
+def test_nagios(capsys, monkeypatch, request, socket_enabled, starter,
+                tmp_path):
     mock_lvalert_client = Mock()
     monkeypatch.setattr(
         'gwcelery.lvalert.client.LVAlertClient', mock_lvalert_client)
-    unix_socket = app.conf['broker_url'].replace('redis+socket://', '')
+    unix_socket = str(tmp_path / 'redis.sock')
+    broker_url = f'redis+socket://{unix_socket}'
+    monkeypatch.setitem(app.conf, 'broker_url', broker_url)
+    monkeypatch.setitem(app.conf, 'result_backend', broker_url)
 
     # no broker
 
     with pytest.raises(SystemExit) as excinfo:
-        app.start(['gwcelery', 'nagios'])
+        main(['gwcelery', 'nagios'])
     assert excinfo.value.code == nagios.NagiosPluginStatus.CRITICAL
     out, err = capsys.readouterr()
     assert 'CRITICAL: No connection to broker' in out
@@ -46,23 +58,20 @@ def test_nagios(capsys, monkeypatch, socket_enabled, starter):
         magic_words=b'The server is now ready to accept connections')
 
     with pytest.raises(SystemExit) as excinfo:
-        app.start(['gwcelery', 'nagios'])
+        main(['gwcelery', 'nagios'])
     assert excinfo.value.code == nagios.NagiosPluginStatus.CRITICAL
     out, err = capsys.readouterr()
     assert 'CRITICAL: Not all expected queues are active' in out
 
     # worker, no LVAlert nodes
 
-    starter.python_process(
-        args=(['gwcelery', 'worker', '-l', 'info', '--pool', 'solo',
-               '-Q', 'celery,exttrig,openmp,superevent,voevent'],),
-        target=app.start, timeout=10, magic_words=b'ready.')
+    request.getfixturevalue('celery_worker')
 
     mock_lvalert_client.configure_mock(**{
         'return_value.get_subscriptions.return_value': {}})
 
     with pytest.raises(SystemExit) as excinfo:
-        app.start(['gwcelery', 'nagios'])
+        main(['gwcelery', 'nagios'])
     assert excinfo.value.code == nagios.NagiosPluginStatus.CRITICAL
     out, err = capsys.readouterr()
     assert 'CRITICAL: Not all lvalert nodes are subscribed' in out
@@ -75,7 +84,7 @@ def test_nagios(capsys, monkeypatch, socket_enabled, starter):
             'lvalert-nodes': expected_lvalert_nodes | {'foobar'}}}))
 
     with pytest.raises(SystemExit) as excinfo:
-        app.start(['gwcelery', 'nagios'])
+        main(['gwcelery', 'nagios'])
     assert excinfo.value.code == nagios.NagiosPluginStatus.CRITICAL
     out, err = capsys.readouterr()
     assert 'CRITICAL: Too many lvalert nodes are subscribed' in out
@@ -87,7 +96,7 @@ def test_nagios(capsys, monkeypatch, socket_enabled, starter):
             'lvalert-nodes': expected_lvalert_nodes}}))
 
     with pytest.raises(SystemExit) as excinfo:
-        app.start(['gwcelery', 'nagios'])
+        main(['gwcelery', 'nagios'])
     assert excinfo.value.code == nagios.NagiosPluginStatus.CRITICAL
     out, err = capsys.readouterr()
     assert 'CRITICAL: The VOEvent broker has no active connections' in out
@@ -100,7 +109,7 @@ def test_nagios(capsys, monkeypatch, socket_enabled, starter):
             'lvalert-nodes': expected_lvalert_nodes}}))
 
     with pytest.raises(SystemExit) as excinfo:
-        app.start(['gwcelery', 'nagios'])
+        main(['gwcelery', 'nagios'])
     assert excinfo.value.code == nagios.NagiosPluginStatus.CRITICAL
     out, err = capsys.readouterr()
     assert 'CRITICAL: The VOEvent receiver has no active connections' in out
@@ -114,7 +123,7 @@ def test_nagios(capsys, monkeypatch, socket_enabled, starter):
                                    'lvalert-nodes': expected_lvalert_nodes}}))
 
     with pytest.raises(SystemExit) as excinfo:
-        app.start(['gwcelery', 'nagios'])
+        main(['gwcelery', 'nagios'])
     assert excinfo.value.code == nagios.NagiosPluginStatus.OK
     out, err = capsys.readouterr()
     assert 'OK: Running normally' in out
